:py:mod:`transform_template_com`
================================

.. py:module:: transform_template_com


Module Contents
---------------

.. py:data:: current_dir
   

   

.. py:data:: current_dir
   

   

.. py:data:: Exec
   

   Properties of the generated Node


.. py:data:: BaseName
   :annotation: = Transform Template

   

.. py:data:: NodeAttributeNames
   :annotation: = ['Parameters', 'Something In 1', 'Something In 2', 'Something Out 1', 'Something Out 2']

   

.. py:data:: NodeAttributeType
   :annotation: = ['Static', 'Input', 'Input', 'Output', 'Output']

   

.. py:data:: ParameterNames
   :annotation: = ['Visualisation', 'Parameter 1', 'Parameter 2', 'Parameter 3', 'Parameter 4']

   

.. py:data:: ParameterTypes
   :annotation: = ['bool', 'str', 'list', 'float', 'int']

   

.. py:data:: ParametersDefaultValues
   :annotation: = [False, 'True', ['item 1', 'item 2'], 0.0, 2]

   

.. py:data:: WorkerDefaultExecutable
   

   

.. py:data:: transform_template_com
   

   

